# [Dreamy Utilities](https://github.com/DreamCobbler/dreamy-utilities) (*1.0.0*)

A set of various utilities for [Python](https://www.python.org/) applications.

I've found myself copy-pasting the same functions over and over again in my Python projects, and so I've decided to make a library out of them. **Dreamy Utilities** are currently extensively used by **[fiction-dl](https://github.com/DreamCobbler/fiction-dl)** 1.6.0.

## ✿ Documentation

The documentation can be found in the *Docs/Code Documentation/* directory.

## ✿ License

**GNU GPL 3**. The text of the license is provided in the *LICENSE* file.